@@ -254,11 +254,11 @@ class Module:
         if not self.client:
             raise error("Client not initialized")
 
+        loop = asyncio.get_running_loop()
+
         def handler(c, u, message):
             if asyncio.iscoroutinefunction(cb):
-                async def subhandler():
-                    await cb(message.topic, message.payload)
-                asyncio.run(subhandler)
+                loop.create_task(cb(message.topic, message.payload))
             else:
                 cb(message.topic, message.payload)
 
